@@ -11,11 +11,11 @@ def check_type(actual, definition):
     # For comparisons to work out the box, first convert from builtin to typing equivilant
     try:
         actual = TYPING_MAP[actual]
-    except KeyError:
+    except (KeyError, TypeError):
         pass
     try:
         definition = TYPING_MAP[definition]
-    except KeyError:
+    except (KeyError, TypeError):
         pass
 
     # Currently any type variable will be considered generic
@@ -29,7 +29,13 @@ def check_type(actual, definition):
     # Currently support list, set, dict and union
     if hasattr(definition, "__origin__"):
         if hasattr(actual, "__origin__"):
-            return issubclass(actual.__origin__, definition.__origin__) and all(
+            try:
+                # For the case where typing.Iterable is good for typing.List
+                class_similarity = issubclass(actual.__origin__, definition.__origin__)
+            except TypeError:
+                class_similarity = actual.__origin__ == definition.__origin__
+
+            return class_similarity and all(
                 check_type(actual.__args__[i], definition.__args__[i])
                 for i in range(len(actual.__args__))
             )
